@@ -211,13 +211,13 @@ from abc import ABC, abstractmethod
 from configparser import NoSectionError
 from typing import Any, Dict, Tuple, List, Optional
 
-from ae.updater import check_all                # type: ignore
-from ae.console import ConsoleApp               # type: ignore
+from ae.updater import check_all                    # type: ignore
+from ae.console import ConsoleApp                   # type: ignore
 
-from ae.files import FilesRegister, CachedFile  # type: ignore
+from ae.files import FilesRegister, RegisteredFile  # type: ignore
 
 
-__version__ = '0.0.8'
+__version__ = '0.0.10'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -228,8 +228,8 @@ APP_STATE_SECTION_NAME = 'aeAppState'           #: config section name for to st
 APP_STATE_VERSION_VAR_NAME = 'app_state_version'
 APP_STATE_CURRENT_VERSION = 2                   #: current application state version
 
-MIN_FONT_SIZE = 15                              #: minimum font size in pixels
-MAX_FONT_SIZE = 99                              #: maximum font size in pixels
+MIN_FONT_SIZE = 15.0                            #: minimum font size in pixels
+MAX_FONT_SIZE = 99.0                            #: maximum font size in pixels
 
 THEME_LIGHT_BACKGROUND_COLOR = (1, 1, 1, 1)     #: light theme background color in rgba(0.0 ... 1.0)
 THEME_LIGHT_FONT_COLOR = (0, 0, 0, 1)           #: light theme font color in rgba(0.0 ... 1.0)
@@ -349,33 +349,31 @@ class MainAppBase(ConsoleApp, ABC):
         self.change_app_state('context_path', self.context_path)
         self.change_app_state('context_id', next_context_id or list_name)
 
-    def find_image_file(self, image_name: str, height: float = 32.0, light_theme: bool = True) -> str:
+    def find_image(self, image_name: str, height: float = 32.0, light_theme: bool = True) -> Optional[RegisteredFile]:
         """ find best fitting image in img app folder.
 
         :param image_name:      name of the image (file name without extension).
         :param height:          preferred height of the image/icon.
         :param light_theme:     preferred theme (dark/light) of the image.
-        :return:                image file path if found else empty string.
+        :return:                image file object (RegisteredFile/CachedFile) if found else None.
         """
         def property_matcher(file):
-            """ find images with enough height """
-            return file.properties.get('height', 32.0) >= height and bool(file.properties.get('dark', 0)) != light_theme
+            """ find images with matching theme. """
+            return bool(file.properties.get('dark', 0)) != light_theme
 
         def file_sorter(file):
-            """ sort images files by height. """
-            return file.properties.get('height', 99999)
+            """ sort images files by height delta. """
+            return abs(file.properties.get('height', 0.0) - height)
 
         if self.image_files:
-            img_file = self.image_files(image_name, property_matcher=property_matcher, file_sorter=file_sorter)
-            if img_file:
-                return img_file.path
-        return ''
+            return self.image_files(image_name, property_matcher=property_matcher, file_sorter=file_sorter)
+        return None
 
-    def find_sound(self, sound_name: str) -> Optional[CachedFile]:
+    def find_sound(self, sound_name: str) -> Optional[RegisteredFile]:
         """ find sound by name.
 
         :param sound_name:      name of the sound to search for.
-        :return:                cached sound file if sound name was found else None.
+        :return:                cached sound file object (RegisteredFile/CachedFile) if sound name was found else None.
         """
         if self.sound_files:    # prevent error on app startup (setup_app_states() called before load_images()
             return self.sound_files(sound_name)
